drivers Package — pwman3 0.6 documentation

### Navigation

- index
- modules |
- pwman3 0.6 documentation »

# drivers Package

## `sqlite` Module

SQLite Database implementation.

class `pwman.data.drivers.sqlite.` `SQLite`(filename, dbformat=0.6)

  Bases: `pwman.data.database.Database`

  `add_node`(node)
  classmethod `check_db_version`(fname)

    check the database version.

  `close`()
  `editnode`(nid, **kwargs)
  `fetch_crypto_info`()
  `getnodes`(ids)

    get nodes as raw ciphertext

  `listnodes`(filter=None)

    return a list of node ids

  `listtags`()
  `loadkey`()

    return _keycrypted

  `removenodes`(nids)
  `save_crypto_info`(seed, digest)

    save the random seed and the digested key

  `savekey`(key)

### Navigation

- index
- modules |
- pwman3 0.6 documentation »